==> org.eclipse.papyrus.uml.profile.assistants.generator.source_1.1.3.201511250900.jar: org/eclipse/papyrus/uml/profile/assistants/generator/ConnectionAssistantRule.java <==
/**
 * Copyright (c) 2014, 2015 Christian W. Damus and others.
 * 
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *   Christian W. Damus - Initial API and implementation
 */
package org.eclipse.papyrus.uml.profile.assistants.generator;

import java.util.ArrayList;
import java.util.HashMap;
import javax.inject.Inject;
import javax.inject.Singleton;
import org.eclipse.papyrus.infra.elementtypesconfigurations.ElementTypeConfiguration;
import org.eclipse.papyrus.infra.filters.Filter;
import org.eclipse.papyrus.infra.gmfdiag.assistant.AssistantFactory;
import org.eclipse.papyrus.infra.gmfdiag.assistant.ConnectionAssistant;
import org.eclipse.papyrus.infra.gmfdiag.assistant.ElementTypeFilter;
import org.eclipse.papyrus.uml.profile.assistants.generator.FiltersUtil;
import org.eclipse.papyrus.uml.profile.elementtypesconfigurations.generator.Identifiers;
import org.eclipse.papyrus.uml.profile.elementtypesconfigurations.generator.ImpliedExtension;
import org.eclipse.papyrus.uml.profile.elementtypesconfigurations.generator.UML;
import org.eclipse.papyrus.uml.profile.elementtypesconfigurations.generator.UMLElementTypes;
import org.eclipse.uml2.uml.Profile;
import org.eclipse.xtext.xbase.lib.CollectionLiterals;
import org.eclipse.xtext.xbase.lib.Extension;
import org.eclipse.xtext.xbase.lib.Functions.Function1;
import org.eclipse.xtext.xbase.lib.Functions.Function2;
import org.eclipse.xtext.xbase.lib.IterableExtensions;

/**
 * Transformation rule for generating a {@link ConnectionAssistant} from a UML {@link Extension}.
 */
@Singleton
@SuppressWarnings("all")
public class ConnectionAssistantRule {
  @Extension
  private static AssistantFactory assistantFactory = AssistantFactory.eINSTANCE;
  
  @Inject
  @Extension
  private Identifiers _identifiers;
  
  @Inject
  @Extension
  private UMLElementTypes _uMLElementTypes;
  
  @Inject
  @Extension
  private FiltersUtil _filtersUtil;
  
  @Inject
  @Extension
  private UML _uML;
  
  public ConnectionAssistant toConnectionAssistant(final ImpliedExtension umlExtension, final ElementTypeConfiguration basetype) {
    final ArrayList<?> _cacheKey = CollectionLiterals.newArrayList(umlExtension, basetype);
    final ConnectionAssistant _result;
    synchronized (_createCache_toConnectionAssistant) {
      if (_createCache_toConnectionAssistant.containsKey(_cacheKey)) {
        return _createCache_toConnectionAssistant.get(_cacheKey);
      }
      ConnectionAssistant _createConnectionAssistant = ConnectionAssistantRule.assistantFactory.createConnectionAssistant();
      _result = _createConnectionAssistant;
      _createCache_toConnectionAssistant.put(_cacheKey, _result);
    }
    _init_toConnectionAssistant(_result, umlExtension, basetype);
    return _result;
  }
  
  private final HashMap<ArrayList<?>, ConnectionAssistant> _createCache_toConnectionAssistant = CollectionLiterals.newHashMap();
  
  private void _init_toConnectionAssistant(final ConnectionAssistant it, final ImpliedExtension umlExtension, final ElementTypeConfiguration basetype) {
    String _elementTypeID = this._identifiers.toElementTypeID(umlExtension, basetype);
    it.setElementTypeID(_elementTypeID);
    Filter _createPossibleSourcesFilter = this.createPossibleSourcesFilter(basetype, umlExtension);
    Filter _reduce = this._filtersUtil.reduce(_createPossibleSourcesFilter);
    Profile _profile = this._uML.getProfile(umlExtension);
    Filter _andProfileApplied = this._filtersUtil.andProfileApplied(_reduce, _profile);
    it.setOwnedSourceFilter(_andProfileApplied);
    Filter _createPossibleTargetsFilter = this.createPossibleTargetsFilter(basetype, umlExtension);
    Filter _reduce_1 = this._filtersUtil.reduce(_createPossibleTargetsFilter);
    Profile _profile_1 = this._uML.getProfile(umlExtension);
    Filter _andProfileApplied_1 = this._filtersUtil.andProfileApplied(_reduce_1, _profile_1);
    it.setOwnedTargetFilter(_andProfileApplied_1);
  }
  
  private Filter createPossibleSourcesFilter(final ElementTypeConfiguration basetype, final ImpliedExtension umlExtension) {
    Iterable<ElementTypeConfiguration> _baseElementTypes = this._uMLElementTypes.getBaseElementTypes();
    final Function1<ElementTypeConfiguration, Boolean> _function = new Function1<ElementTypeConfiguration, Boolean>() {
      public Boolean apply(final ElementTypeConfiguration it) {
        boolean _isRelationship = ConnectionAssistantRule.this._uMLElementTypes.isRelationship(it);
        return Boolean.valueOf((!_isRelationship));
      }
    };
    Iterable<ElementTypeConfiguration> _filter = IterableExtensions.<ElementTypeConfiguration>filter(_baseElementTypes, _function);
    final Function2<Filter, ElementTypeConfiguration, Filter> _function_1 = new Function2<Filter, ElementTypeConfiguration, Filter>() {
      public Filter apply(final Filter filter, final ElementTypeConfiguration elementType) {
        Filter _xifexpression = null;
        boolean _canSourceToType = ConnectionAssistantRule.this._uMLElementTypes.canSourceToType(elementType, basetype);
        if (_canSourceToType) {
          Profile _profile = ConnectionAssistantRule.this._uML.getProfile(umlExtension);
          ElementTypeFilter _filter = ConnectionAssistantRule.this._filtersUtil.toFilter(elementType, _profile);
          _xifexpression = ConnectionAssistantRule.this._filtersUtil.operator_or(filter, _filter);
        } else {
          _xifexpression = filter;
        }
        return _xifexpression;
      }
    };
    return IterableExtensions.<ElementTypeConfiguration, Filter>fold(_filter, null, _function_1);
  }
  
  private Filter createPossibleTargetsFilter(final ElementTypeConfiguration basetype, final ImpliedExtension umlExtension) {
    Iterable<ElementTypeConfiguration> _baseElementTypes = this._uMLElementTypes.getBaseElementTypes();
    final Function1<ElementTypeConfiguration, Boolean> _function = new Function1<ElementTypeConfiguration, Boolean>() {
      public Boolean apply(final ElementTypeConfiguration it) {
        boolean _isRelationship = ConnectionAssistantRule.this._uMLElementTypes.isRelationship(it);
        return Boolean.valueOf((!_isRelationship));
      }
    };
    Iterable<ElementTypeConfiguration> _filter = IterableExtensions.<ElementTypeConfiguration>filter(_baseElementTypes, _function);
    final Function2<Filter, ElementTypeConfiguration, Filter> _function_1 = new Function2<Filter, ElementTypeConfiguration, Filter>() {
      public Filter apply(final Filter filter, final ElementTypeConfiguration elementType) {
        Filter _xifexpression = null;
        boolean _canTargetFromType = ConnectionAssistantRule.this._uMLElementTypes.canTargetFromType(elementType, basetype);
        if (_canTargetFromType) {
          Profile _profile = ConnectionAssistantRule.this._uML.getProfile(umlExtension);
          ElementTypeFilter _filter = ConnectionAssistantRule.this._filtersUtil.toFilter(elementType, _profile);
          _xifexpression = ConnectionAssistantRule.this._filtersUtil.operator_or(filter, _filter);
        } else {
          _xifexpression = filter;
        }
        return _xifexpression;
      }
    };
    return IterableExtensions.<ElementTypeConfiguration, Filter>fold(_filter, null, _function_1);
  }
}

==> org.eclipse.papyrus.uml.profile.assistants.generator.source_2.0.0.201606080854.jar: org/eclipse/papyrus/uml/profile/assistants/generator/ConnectionAssistantRule.java <==
/**
 * Copyright (c) 2014, 2015 Christian W. Damus and others.
 * 
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *   Christian W. Damus - Initial API and implementation
 */
package org.eclipse.papyrus.uml.profile.assistants.generator;

import java.util.ArrayList;
import java.util.HashMap;
import javax.inject.Inject;
import javax.inject.Singleton;
import org.eclipse.papyrus.infra.filters.Filter;
import org.eclipse.papyrus.infra.gmfdiag.assistant.AssistantFactory;
import org.eclipse.papyrus.infra.gmfdiag.assistant.ConnectionAssistant;
import org.eclipse.papyrus.infra.gmfdiag.assistant.ElementTypeFilter;
import org.eclipse.papyrus.infra.types.ElementTypeConfiguration;
import org.eclipse.papyrus.uml.profile.assistants.generator.FiltersUtil;
import org.eclipse.papyrus.uml.profile.types.generator.Identifiers;
import org.eclipse.papyrus.uml.profile.types.generator.ImpliedExtension;
import org.eclipse.papyrus.uml.profile.types.generator.UML;
import org.eclipse.papyrus.uml.profile.types.generator.UMLElementTypes;
import org.eclipse.uml2.uml.Profile;
import org.eclipse.xtext.xbase.lib.CollectionLiterals;
import org.eclipse.xtext.xbase.lib.Extension;
import org.eclipse.xtext.xbase.lib.Functions.Function1;
import org.eclipse.xtext.xbase.lib.Functions.Function2;
import org.eclipse.xtext.xbase.lib.IterableExtensions;

/**
 * Transformation rule for generating a {@link ConnectionAssistant} from a UML {@link Extension}.
 */
@Singleton
@SuppressWarnings("all")
public class ConnectionAssistantRule {
  @Extension
  private static AssistantFactory assistantFactory = AssistantFactory.eINSTANCE;
  
  @Inject
  @Extension
  private Identifiers _identifiers;
  
  @Inject
  @Extension
  private UMLElementTypes _uMLElementTypes;
  
  @Inject
  @Extension
  private FiltersUtil _filtersUtil;
  
  @Inject
  @Extension
  private UML _uML;
  
  public ConnectionAssistant toConnectionAssistant(final ImpliedExtension umlExtension, final ElementTypeConfiguration basetype) {
    final ArrayList<?> _cacheKey = CollectionLiterals.newArrayList(umlExtension, basetype);
    final ConnectionAssistant _result;
    synchronized (_createCache_toConnectionAssistant) {
      if (_createCache_toConnectionAssistant.containsKey(_cacheKey)) {
        return _createCache_toConnectionAssistant.get(_cacheKey);
      }
      ConnectionAssistant _createConnectionAssistant = ConnectionAssistantRule.assistantFactory.createConnectionAssistant();
      _result = _createConnectionAssistant;
      _createCache_toConnectionAssistant.put(_cacheKey, _result);
    }
    _init_toConnectionAssistant(_result, umlExtension, basetype);
    return _result;
  }
  
  private final HashMap<ArrayList<?>, ConnectionAssistant> _createCache_toConnectionAssistant = CollectionLiterals.newHashMap();
  
  private void _init_toConnectionAssistant(final ConnectionAssistant it, final ImpliedExtension umlExtension, final ElementTypeConfiguration basetype) {
    String _elementTypeID = this._identifiers.toElementTypeID(umlExtension, basetype);
    it.setElementTypeID(_elementTypeID);
    Filter _createPossibleSourcesFilter = this.createPossibleSourcesFilter(basetype, umlExtension);
    Filter _reduce = this._filtersUtil.reduce(_createPossibleSourcesFilter);
    Profile _profile = this._uML.getProfile(umlExtension);
    Filter _andProfileApplied = this._filtersUtil.andProfileApplied(_reduce, _profile);
    it.setOwnedSourceFilter(_andProfileApplied);
    Filter _createPossibleTargetsFilter = this.createPossibleTargetsFilter(basetype, umlExtension);
    Filter _reduce_1 = this._filtersUtil.reduce(_createPossibleTargetsFilter);
    Profile _profile_1 = this._uML.getProfile(umlExtension);
    Filter _andProfileApplied_1 = this._filtersUtil.andProfileApplied(_reduce_1, _profile_1);
    it.setOwnedTargetFilter(_andProfileApplied_1);
  }
  
  private Filter createPossibleSourcesFilter(final ElementTypeConfiguration basetype, final ImpliedExtension umlExtension) {
    Iterable<ElementTypeConfiguration> _baseElementTypes = this._uMLElementTypes.getBaseElementTypes();
    final Function1<ElementTypeConfiguration, Boolean> _function = new Function1<ElementTypeConfiguration, Boolean>() {
      public Boolean apply(final ElementTypeConfiguration it) {
        boolean _isRelationship = ConnectionAssistantRule.this._uMLElementTypes.isRelationship(it);
        return Boolean.valueOf((!_isRelationship));
      }
    };
    Iterable<ElementTypeConfiguration> _filter = IterableExtensions.<ElementTypeConfiguration>filter(_baseElementTypes, _function);
    final Function2<Filter, ElementTypeConfiguration, Filter> _function_1 = new Function2<Filter, ElementTypeConfiguration, Filter>() {
      public Filter apply(final Filter filter, final ElementTypeConfiguration elementType) {
        Filter _xifexpression = null;
        boolean _canSourceToType = ConnectionAssistantRule.this._uMLElementTypes.canSourceToType(elementType, basetype);
        if (_canSourceToType) {
          Profile _profile = ConnectionAssistantRule.this._uML.getProfile(umlExtension);
          ElementTypeFilter _filter = ConnectionAssistantRule.this._filtersUtil.toFilter(elementType, _profile);
          _xifexpression = ConnectionAssistantRule.this._filtersUtil.operator_or(filter, _filter);
        } else {
          _xifexpression = filter;
        }
        return _xifexpression;
      }
    };
    return IterableExtensions.<ElementTypeConfiguration, Filter>fold(_filter, null, _function_1);
  }
  
  private Filter createPossibleTargetsFilter(final ElementTypeConfiguration basetype, final ImpliedExtension umlExtension) {
    Iterable<ElementTypeConfiguration> _baseElementTypes = this._uMLElementTypes.getBaseElementTypes();
    final Function1<ElementTypeConfiguration, Boolean> _function = new Function1<ElementTypeConfiguration, Boolean>() {
      public Boolean apply(final ElementTypeConfiguration it) {
        boolean _isRelationship = ConnectionAssistantRule.this._uMLElementTypes.isRelationship(it);
        return Boolean.valueOf((!_isRelationship));
      }
    };
    Iterable<ElementTypeConfiguration> _filter = IterableExtensions.<ElementTypeConfiguration>filter(_baseElementTypes, _function);
    final Function2<Filter, ElementTypeConfiguration, Filter> _function_1 = new Function2<Filter, ElementTypeConfiguration, Filter>() {
      public Filter apply(final Filter filter, final ElementTypeConfiguration elementType) {
        Filter _xifexpression = null;
        boolean _canTargetFromType = ConnectionAssistantRule.this._uMLElementTypes.canTargetFromType(elementType, basetype);
        if (_canTargetFromType) {
          Profile _profile = ConnectionAssistantRule.this._uML.getProfile(umlExtension);
          ElementTypeFilter _filter = ConnectionAssistantRule.this._filtersUtil.toFilter(elementType, _profile);
          _xifexpression = ConnectionAssistantRule.this._filtersUtil.operator_or(filter, _filter);
        } else {
          _xifexpression = filter;
        }
        return _xifexpression;
      }
    };
    return IterableExtensions.<ElementTypeConfiguration, Filter>fold(_filter, null, _function_1);
  }
}
